Crate solar_core

Crate solar_core 

Re-exports

pub use tool::Action;
pub use tool::CargoDeny;
pub use tool::Commitalyzer;
pub use tool::GithubWorkflows;
pub use tool::LICENSES_DIR;
pub use tool::Licenses;
pub use tool::PreCommit;
pub use tool::SemverRelease;
pub use tool::Tool;
pub use tool::ToolTrait;
pub use tool::Vhooks;

Modules

tool

Structs

Config
Global
Init
Install
New
SolarCommand
SolarError
Update
Upgrade

Enums

Subcommand
UnitCommand

Constants

SOLARCONFIGNAME

Functions

solar_init
solar_new
solar_update
sorted
Method that provides a sorted collection. Takes ownership of the collection, mutates it in place, then returns it as an owned value. Useful if you just want a one-liner to get a sorted collection rather than a separate line to sort the collection after its instantiated, especially if you don’t want the collection to be mutable after sorting.