pub struct Global {}Implementations
Sourceimpl Global
impl Global
Sourcepub fn is_git(destination: &Path) -> Result<bool, SolarError>
pub fn is_git(destination: &Path) -> Result<bool, SolarError>
Returns whether the path is a git repository or not.
pub fn ovrwrt_file_or_default(file_path: &Path) -> Result<File, SolarError>
Sourcepub fn git_init(destination: &Path) -> Result<(), SolarError>
pub fn git_init(destination: &Path) -> Result<(), SolarError>
Initialize a git repository at the destination if it’s not already.
pub fn git_hooks_path(path: &Path) -> Result<PathBuf, SolarError>
pub fn default_git_hook_dir() -> PathBuf
pub fn licenses_url(spdx: &str) -> Result<Url, SolarError>
pub fn commitalyzer_exec_download() -> Result<Url, SolarError>
pub fn commitalyzer_conventional_commits_ruleset() -> Result<Url, SolarError>
pub fn semver_release_exec_download() -> Result<Url, SolarError>
pub fn semver_release_config_url() -> Result<Url, SolarError>
pub fn semver_cargo_exec_download() -> Result<Url, SolarError>