pub struct Vhooks { /* private fields */ }Implementations
Sourceimpl Vhooks
Auto-generated by derive_getters::Getters.
impl Vhooks
Auto-generated by derive_getters::Getters.
Sourcepub fn destination(&self) -> &PathBuf
pub fn destination(&self) -> &PathBuf
The working directory to use for installation.
Sourcepub fn remove_all(&self) -> &bool
pub fn remove_all(&self) -> &bool
Whether to remove all hooks when removing vhooks, or just put thim in unversioned git hooks directory.