Tool

Enum Tool 

pub enum Tool {
    VHOOKS(Vhooks),
    COMMITALYZER(Commitalyzer),
    SEMVERRELEASE(SemverRelease),
    LICENSES(Licenses),
    WORKSPACES(Workspaces),
    PRECOMMIT(PreCommit),
    DENY(CargoDeny),
}

Variants



VHOOKS(Vhooks)

Configures a versioned git hook folder for a project.



COMMITALYZER(Commitalyzer)

Installs commitalyzer (git commit linting tool) to the git hooks directory.



SEMVERRELEASE(SemverRelease)

Installs and configured SemVer-Release in the project.



LICENSES(Licenses)

Installs the appropriate licenses into the project.



WORKSPACES(Workspaces)

Configures project with standard Github workflows.



PRECOMMIT(PreCommit)

Configures project with a standard pre-commit hook for rust.



DENY(CargoDeny)

Configures project with a cargo deny for license checking.

Implementations

Source

impl Tool

pub fn perform(arg: &Option<Self>, action: Action) -> Result<(), SolarError>